"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const run_1 = require("../../base/run");
const docker_run_1 = require("../../core/docker.run");
const conf_1 = require("../../services/conf");
const util_1 = require("../../util");
class DockerRun extends run_1.default {
    constructor() {
        super(...arguments);
        this.json = false;
    }
    async preInit() {
        await super.preInit();
        const { flags } = this.parse(DockerRun);
        this.json = flags.json;
    }
    async preRun() {
        const core = new docker_run_1.default({
            watch: this.watch,
        });
        await core.start();
    }
    async run() {
        process.env.PATH = `${process.env.PATH}:${conf_1.default.dockerWorkDirRoot}/node_modules/.bin`;
        let args = ['run', `${this.cmd}`];
        if (this.json) {
            args = args.concat(['--', '--format', 'json']);
        }
        await util_1.default.asyncSpawn('npm', args, {
            cwd: conf_1.default.runtimeDir,
            env: process.env
        });
    }
}
DockerRun.description = 'run script inside docker container';
DockerRun.examples = [
    '$ rde docker:run <cmd>',
];
DockerRun.args = [...run_1.default.args];
DockerRun.flags = Object.assign({}, run_1.default.flags, { json: command_1.flags.boolean({
        description: 'using with lint, format output to json',
    }) });
exports.default = DockerRun;
